@@ -307,8 +307,12 @@ class Job(BaseController):
         Returns:
         """
         if block:
-            self.wait_for_finish(block_timeout)
+            self.wait_for_finish(timeout=block_timeout)
 
+        task_results = self._download_task_results()
+        return task_results
+
+    def _download_task_results(self):
         response = self.stream(f"/jobs/{self.job_id}/result")
 
         archive = zip_tools.unzip_in_memory(response)
