@@ -432,9 +432,9 @@ class TestJobCommands(BaseTest):
     @patch('disco.gql.authentication.Authentication.is_logged_in')
     @patch('disco.Job.create')
     @patch('disco.asset.Asset.upload')
-    def test_create_job_quite_mode(self, asset_upload_mock, job_create_mock, is_logged_in_mock):
+    def test_create_job_quiet_mode(self, asset_upload_mock, job_create_mock, is_logged_in_mock):
         """
-        Run create job in quite mode
+        Run create job in quiet mode
         """
         is_logged_in_mock.return_value = True
         job_create_mock.return_value = Job("job_id")
@@ -443,7 +443,7 @@ class TestJobCommands(BaseTest):
         with runner.isolated_filesystem():
             with open('script_file.py', 'w') as f:
                 f.write("print('hi!')")
-                result = runner.invoke(cli, "job create -n job_name -s script_file.py --quite")
+                result = runner.invoke(cli, "job create -n job_name -s script_file.py --quiet")
                 assert result.exit_code == 0
                 assert output_message_includes(result, 'Created job with id job_id')
                 job_create_mock.assert_called_with(script_file_id='file_id', input_file_ids=[], constants_file_ids=[],
@@ -457,9 +457,9 @@ class TestJobCommands(BaseTest):
     @patch('disco.gql.authentication.Authentication.is_logged_in')
     @patch('disco.Job.create')
     @patch('disco.asset.Asset.upload')
-    def test_create_job_quite_mode_disabled_by_default(self, asset_upload_mock, job_create_mock, is_logged_in_mock):
+    def test_create_job_quiet_mode_disabled_by_default(self, asset_upload_mock, job_create_mock, is_logged_in_mock):
         """
-        Run create job, quite mode disabled by default
+        Run create job, quiet mode disabled by default
         """
         is_logged_in_mock.return_value = True
         job_create_mock.return_value = Job("job_id")
